define("epi-cms/project/ProjectItemQueryEngine", [
    "epi-cms/core/ContentReference",
    "epi-cms/store/queryUtils"
], function(
    ContentReference,
    queryUtils
){
    return function(query, options){
        // summary:
        //      A QueryEngine configured to work with project items.
        //
        // query: Object
        //
        // options: dojo/store/api/Store.QueryOptions?
        //		An object that contains optional information such as sort, start, and count
        //
        // returns: Function
        //		A QueryEngine matching the queries sent to the ProjectItemStore

        var filter, sorter, engine;

        options = options || {};

        options.comparers = {
            contentLinks: function (queryValue, instance) {
                return queryValue.some(function (link) {
                    return ContentReference.compareIgnoreVersion(link, instance.contentLink);
                });
            }
        };

        filter = queryUtils.createFilter(query, options);
        sorter = queryUtils.createSorter(options.sort);
        engine = queryUtils.createExecuter(filter, sorter, options.start, options.count);

        engine.matches = filter;

        return engine;

    };
});
